summary refs log tree commit diff
path: root/pkgs/development/libraries/webkitgtk
diff options
context:
space:
mode:
authorAngus Trau <me@angus.ws>2021-07-31 21:36:43 +1000
committerRaphael Megzari <raphael@megzari.com>2021-08-10 14:59:05 +0900
commit44b130d392ac6391d801372fc2a8dbf8b655f9db (patch)
tree4a110c1b33c6ecd379c766eca076f5ab45459df3 /pkgs/development/libraries/webkitgtk
parent2457ddc9522b0861649ee5e952fa2e505c1743b7 (diff)
downloadnixpkgs-44b130d392ac6391d801372fc2a8dbf8b655f9db.tar
nixpkgs-44b130d392ac6391d801372fc2a8dbf8b655f9db.tar.gz
nixpkgs-44b130d392ac6391d801372fc2a8dbf8b655f9db.tar.bz2
nixpkgs-44b130d392ac6391d801372fc2a8dbf8b655f9db.tar.lz
nixpkgs-44b130d392ac6391d801372fc2a8dbf8b655f9db.tar.xz
nixpkgs-44b130d392ac6391d801372fc2a8dbf8b655f9db.tar.zst
nixpkgs-44b130d392ac6391d801372fc2a8dbf8b655f9db.zip
webkitgtk: remove reference to private Apple SDK
Diffstat (limited to 'pkgs/development/libraries/webkitgtk')
-rw-r--r--pkgs/development/libraries/webkitgtk/default.nix14
1 files changed, 8 insertions, 6 deletions
diff --git a/pkgs/development/libraries/webkitgtk/default.nix b/pkgs/development/libraries/webkitgtk/default.nix
index 72b09fec29d..8c5a8d6306a 100644
--- a/pkgs/development/libraries/webkitgtk/default.nix
+++ b/pkgs/development/libraries/webkitgtk/default.nix
@@ -36,7 +36,7 @@
 , libidn
 , libedit
 , readline
-, sdk
+, apple_sdk
 , libGL
 , libGLU
 , mesa
@@ -167,13 +167,15 @@ stdenv.mkDerivation rec {
   ]) ++ lib.optionals stdenv.isDarwin [
     libedit
     readline
+  ] ++ lib.optional (stdenv.isDarwin && !stdenv.isAarch64) (
     # Pull a header that contains a definition of proc_pid_rusage().
     # (We pick just that one because using the other headers from `sdk` is not
-    # compatible with our C++ standard library)
-    (runCommandNoCC "${pname}_headers" {} ''
-      install -Dm444 "${lib.getDev sdk}"/include/libproc.h "$out"/include/libproc.h
-    '')
-  ] ++ lib.optionals stdenv.isLinux [
+    # compatible with our C++ standard library. This header is already in
+    # the standard library on aarch64)
+    runCommandNoCC "${pname}_headers" {} ''
+      install -Dm444 "${lib.getDev apple_sdk.sdk}"/include/libproc.h "$out"/include/libproc.h
+    ''
+  ) ++ lib.optionals stdenv.isLinux [
     bubblewrap
     libseccomp
     systemd